# API Documentation

```{eval-rst}
.. currentmodule:: qualpal
```

## Classes

```{eval-rst}
.. currentmodule::  qualpal

.. autosummary::
   :toctree: generated
   :template: class.rst

    Color
    Palette
    Qualpal
```
